@@ -25,7 +25,6 @@ import pkg_resources
 from . import geotime_schema
 # When working locally. use this.
 # import geotime_schema
-from datetime import datetime, timedelta
 import time
 
 import logging
@@ -1198,6 +1197,7 @@ class GeoTimeClassify:
                 return build_return_object(format=monthFormat + "_" + dayFormat + "_%y", util='Util', dayFirst=dayFirst)
 
         def date_util_5(values):
+            print('made it', values)
             array_valid, dayFirst = date_util(values, separator="/", shortyear=False, yearloc=None)
             if dayFirst:
                 dayFormat = day_ddOrd(values, separator='/', loc=0)
@@ -1218,6 +1218,7 @@ class GeoTimeClassify:
                 return build_return_standard_object(category=None, subcategory=None, match_type=None)
 
         def date_util_6(values):
+            print(values)
             array_valid, dayFirst = date_util(values, separator="/", shortyear=True, yearloc=2)
             if dayFirst:
                 dayFormat = day_ddOrd(values, separator='/', loc=0)
